[][src]Struct google_admin1_directory::AppAccessCollections

pub struct AppAccessCollections {
    pub kind: Option<String>,
    pub trust_domain_owned_apps: Option<bool>,
    pub resource_id: Option<String>,
    pub error_message: Option<String>,
    pub etag: Option<String>,
    pub blocked_api_access_buckets: Option<Vec<String>>,
    pub resource_name: Option<String>,
    pub enforce_settings_for_android_drive: Option<bool>,
}

JSON template for App Access Collections Resource object in Directory API.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

kind: Option<String>

Identifies the resource as an app access collection. Value: admin#directory#appaccesscollection

trust_domain_owned_apps: Option<bool>

Boolean that indicates whether to trust domain owned apps.

resource_id: Option<String>

Unique ID of app access collection. (Readonly)

error_message: Option<String>

Error message provided by the Admin that will be shown to the user when an app is blocked.

etag: Option<String>

ETag of the resource.

blocked_api_access_buckets: Option<Vec<String>>

List of blocked api access buckets.

resource_name: Option<String>

Resource name given by the customer while creating/updating. Should be unique under given customer.

enforce_settings_for_android_drive: Option<bool>

Boolean to indicate whether to enforce app access settings on Android Drive or not.