pub struct Asp {
pub kind: Option<String>,
pub etag: Option<String>,
pub name: Option<String>,
pub code_id: Option<i32>,
pub last_time_used: Option<String>,
pub user_key: Option<String>,
pub creation_time: Option<String>,
}Expand description
The template that returns individual ASP (Access Code) data.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list asps (none)
- delete asps (none)
- get asps (response)
Fields
kind: Option<String>The type of the API resource. This is always admin#directory#asp.
etag: Option<String>ETag of the ASP.
name: Option<String>The name of the application that the user, represented by their userId, entered when the ASP was created.
code_id: Option<i32>The unique ID of the ASP.
last_time_used: Option<String>The time when the ASP was last used. Expressed in Unix time format.
user_key: Option<String>The unique ID of the user who issued the ASP.
creation_time: Option<String>The time when the ASP was created. Expressed in Unix time format.