Struct google_admin1_directory::BuildingCoordinates[][src]

pub struct BuildingCoordinates {
    pub latitude: Option<f64>,
    pub longitude: Option<f64>,
}

JSON template for coordinates of a building in Directory API.

This type is not used in any activity, and only used as part of another schema.

Fields

Latitude in decimal degrees.

Longitude in decimal degrees.