pub struct CalendarResources {
pub next_page_token: Option<String>,
pub items: Option<Vec<CalendarResource>>,
pub kind: Option<String>,
pub etag: Option<String>,
}Expand description
JSON template for Calendar Resource List Response object in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- calendars list resources (response)
Fields
next_page_token: Option<String>The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results.
items: Option<Vec<CalendarResource>>The CalendarResources in this page of results.
kind: Option<String>Identifies this as a collection of CalendarResources. This is always admin#directory#resources#calendars#calendarResourcesList.
etag: Option<String>ETag of the resource.