ChromeOsDevice

Struct ChromeOsDevice 

pub struct ChromeOsDevice {
Show 35 fields pub mac_address: Option<String>, pub last_sync: Option<String>, pub order_number: Option<String>, pub annotated_location: Option<String>, pub disk_volume_reports: Option<Vec<ChromeOsDeviceDiskVolumeReports>>, pub active_time_ranges: Option<Vec<ChromeOsDeviceActiveTimeRanges>>, pub system_ram_free_reports: Option<Vec<ChromeOsDeviceSystemRamFreeReports>>, pub annotated_asset_id: Option<String>, pub firmware_version: Option<String>, pub system_ram_total: Option<String>, pub auto_update_expiration: Option<String>, pub ethernet_mac_address0: Option<String>, pub boot_mode: Option<String>, pub etag: Option<String>, pub org_unit_path: Option<String>, pub recent_users: Option<Vec<ChromeOsDeviceRecentUsers>>, pub last_enrollment_time: Option<String>, pub ethernet_mac_address: Option<String>, pub meid: Option<String>, pub annotated_user: Option<String>, pub cpu_status_reports: Option<Vec<ChromeOsDeviceCpuStatusReports>>, pub platform_version: Option<String>, pub os_version: Option<String>, pub dock_mac_address: Option<String>, pub will_auto_renew: Option<bool>, pub kind: Option<String>, pub device_files: Option<Vec<ChromeOsDeviceDeviceFiles>>, pub notes: Option<String>, pub serial_number: Option<String>, pub manufacture_date: Option<String>, pub status: Option<String>, pub support_end_date: Option<String>, pub tpm_version_info: Option<ChromeOsDeviceTpmVersionInfo>, pub model: Option<String>, pub device_id: Option<String>,
}
JSON template for Chrome Os Device resource in Directory API.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

mac_address: Option<String>

Chromebook Mac Address on wifi network interface (Read-only)

last_sync: Option<String>

Date and time the device was last synchronized with the policy settings in the G Suite administrator control panel (Read-only)

order_number: Option<String>

Chromebook order number (Read-only)

annotated_location: Option<String>

Address or location of the device as noted by the administrator

disk_volume_reports: Option<Vec<ChromeOsDeviceDiskVolumeReports>>

Reports of disk space and other info about mounted/connected volumes.

active_time_ranges: Option<Vec<ChromeOsDeviceActiveTimeRanges>>

List of active time ranges (Read-only)

system_ram_free_reports: Option<Vec<ChromeOsDeviceSystemRamFreeReports>>

Reports of amounts of available RAM memory (Read-only)

annotated_asset_id: Option<String>

AssetId specified during enrollment or through later annotation

firmware_version: Option<String>

Chromebook firmware version (Read-only)

system_ram_total: Option<String>

Total RAM on the device [in bytes] (Read-only)

auto_update_expiration: Option<String>

(Read-only) The timestamp after which the device will stop receiving Chrome updates or support

ethernet_mac_address0: Option<String>

(Read-only) MAC address used by the Chromebook’s internal ethernet port, and for onboard network (ethernet) interface. The format is twelve (12) hexadecimal digits without any delimiter (uppercase letters). This is only relevant for some devices.

boot_mode: Option<String>

Chromebook boot mode (Read-only)

etag: Option<String>

ETag of the resource.

org_unit_path: Option<String>

OrgUnit of the device

recent_users: Option<Vec<ChromeOsDeviceRecentUsers>>

List of recent device users, in descending order by last login time (Read-only)

last_enrollment_time: Option<String>

Date and time the device was last enrolled (Read-only)

ethernet_mac_address: Option<String>

Chromebook Mac Address on ethernet network interface (Read-only)

meid: Option<String>

Contains either the Mobile Equipment identifier (MEID) or the International Mobile Equipment Identity (IMEI) for the 3G mobile card in the Chromebook (Read-only)

annotated_user: Option<String>

User of the device

cpu_status_reports: Option<Vec<ChromeOsDeviceCpuStatusReports>>

Reports of CPU utilization and temperature (Read-only)

platform_version: Option<String>

Chromebook platform version (Read-only)

os_version: Option<String>

Chromebook Os Version (Read-only)

dock_mac_address: Option<String>

(Read-only) Built-in MAC address for the docking station that the device connected to. Factory sets Media access control address (MAC address) assigned for use by a dock. Currently this is only supported on the Dell Arcada / Sarien devices and the Dell WD19 / WD19TB Docking Station. It is reserved specifically for MAC pass through device policy. The format is twelve (12) hexadecimal digits without any delimiter (uppercase letters). This is only relevant for Dell devices.

will_auto_renew: Option<bool>

Will Chromebook auto renew after support end date (Read-only)

kind: Option<String>

Kind of resource this is.

device_files: Option<Vec<ChromeOsDeviceDeviceFiles>>

List of device files to download (Read-only)

notes: Option<String>

Notes added by the administrator

serial_number: Option<String>

Chromebook serial number (Read-only)

manufacture_date: Option<String>

(Read-only) The date the device was manufactured in yyyy-mm-dd format.

status: Option<String>

status of the device (Read-only)

support_end_date: Option<String>

Final date the device will be supported (Read-only)

tpm_version_info: Option<ChromeOsDeviceTpmVersionInfo>

Trusted Platform Module (TPM) (Read-only)

model: Option<String>

Chromebook Model (Read-only)

device_id: Option<String>

Unique identifier of Chrome OS Device (Read-only)