pub struct ChromeOsDeviceAction {
pub action: Option<String>,
pub deprovision_reason: Option<String>,
}Expand description
JSON request template for firing actions on ChromeOs Device in Directory Devices API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- action chromeosdevices (request)
Fields
action: Option<String>Action to be taken on the ChromeOs Device
deprovision_reason: Option<String>no description provided