pub struct ChromeOsDeviceRecentUsers {
pub type_: Option<String>,
pub email: Option<String>,
}Expand description
List of recent device users, in descending order by last login time (Read-only)
This type is not used in any activity, and only used as part of another schema.
Fields
type_: Option<String>The type of the user
email: Option<String>Email address of the user. Present only if the user type is managed