CustomerPostalAddress

Struct CustomerPostalAddress 

pub struct CustomerPostalAddress {
    pub organization_name: Option<String>,
    pub country_code: Option<String>,
    pub locality: Option<String>,
    pub region: Option<String>,
    pub address_line2: Option<String>,
    pub address_line3: Option<String>,
    pub contact_name: Option<String>,
    pub address_line1: Option<String>,
    pub postal_code: Option<String>,
}
JSON template for postal address of a customer.

This type is not used in any activity, and only used as part of another schema.

Fields

organization_name: Option<String>

The company or company division name.

country_code: Option<String>

This is a required property. For countryCode information see the ISO 3166 country code elements.

locality: Option<String>

Name of the locality. An example of a locality value is the city of San Francisco.

region: Option<String>

Name of the region. An example of a region value is NY for the state of New York.

address_line2: Option<String>

Address line 2 of the address.

address_line3: Option<String>

Address line 3 of the address.

contact_name: Option<String>

The customer contact’s name.

address_line1: Option<String>

A customer’s physical address. The address can be composed of one to three lines.

postal_code: Option<String>

The postal code. A postalCode example is a postal zip code such as 10009. This is in accordance with - http://portablecontacts.net/draft-spec.html#address_element.