pub struct DomainAliases {
pub domain_aliases: Option<Vec<DomainAlias>>,
pub kind: Option<String>,
pub etag: Option<String>,
}Expand description
JSON response template to list domain aliases in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list domain aliases (response)
Fields
domain_aliases: Option<Vec<DomainAlias>>List of domain alias objects.
kind: Option<String>Kind of resource this is.
etag: Option<String>ETag of the resource.