pub struct Domains {
pub kind: Option<String>,
pub etag: Option<String>,
pub verified: Option<bool>,
pub domain_name: Option<String>,
pub domain_aliases: Option<Vec<DomainAlias>>,
pub is_primary: Option<bool>,
pub creation_time: Option<String>,
}Expand description
JSON template for Domain object in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- insert domains (request|response)
- get domains (response)
Fields
kind: Option<String>Kind of resource this is.
etag: Option<String>ETag of the resource.
verified: Option<bool>Indicates the verification state of a domain. (Read-only).
domain_name: Option<String>The domain name of the customer.
domain_aliases: Option<Vec<DomainAlias>>List of domain alias objects. (Read-only)
is_primary: Option<bool>Indicates if the domain is a primary domain (Read-only).
creation_time: Option<String>Creation time of the domain. (Read-only).