pub struct MobileDevices {
pub next_page_token: Option<String>,
pub kind: Option<String>,
pub etag: Option<String>,
pub mobiledevices: Option<Vec<MobileDevice>>,
}Expand description
JSON response template for List Mobile Devices operation in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list mobiledevices (response)
Fields
next_page_token: Option<String>Token used to access next page of this result.
kind: Option<String>Kind of resource this is.
etag: Option<String>ETag of the resource.
mobiledevices: Option<Vec<MobileDevice>>List of Mobile Device objects.