MobiledeviceListCall

Struct MobiledeviceListCall 

pub struct MobiledeviceListCall<'a, C, A>
where C: 'a, A: 'a,
{ /* private fields */ }
Retrieve all Mobile Devices of a customer (paginated)

A builder for the list method supported by a mobiledevice resource. It is not used directly, but through a MobiledeviceMethods instance.

Example

Instantiate a resource method builder

 
// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.mobiledevices().list("customerId")
             .sort_order("dolore")
             .query("nonumy")
             .projection("sed")
             .page_token("aliquyam")
             .order_by("sit")
             .max_results(-40)
             .doit();

Implementations

Source

impl<'a, C, A> MobiledeviceListCall<'a, C, A>
where C: BorrowMut<Client>, A: GetToken,

pub fn doit(self) -> Result<(Response, MobileDevices)>

Perform the operation you have build so far.

pub fn customer_id(self, new_value: &str) -> MobiledeviceListCall<'a, C, A>

Immutable ID of the G Suite account

Sets the customer id path property to the given value.

Even though the property as already been set when instantiating this call, we provide this method for API completeness.

pub fn sort_order(self, new_value: &str) -> MobiledeviceListCall<'a, C, A>

Whether to return results in ascending or descending order. Only of use when orderBy is also used

Sets the sort order query property to the given value.

pub fn query(self, new_value: &str) -> MobiledeviceListCall<'a, C, A>

Search string in the format given at http://support.google.com/a/bin/answer.py?answer=1408863#search

Sets the query query property to the given value.

pub fn projection(self, new_value: &str) -> MobiledeviceListCall<'a, C, A>

Restrict information returned to a set of selected fields.

Sets the projection query property to the given value.

pub fn page_token(self, new_value: &str) -> MobiledeviceListCall<'a, C, A>

Token to specify next page in the list

Sets the page token query property to the given value.

pub fn order_by(self, new_value: &str) -> MobiledeviceListCall<'a, C, A>

Column to use for sorting results

Sets the order by query property to the given value.

pub fn max_results(self, new_value: i32) -> MobiledeviceListCall<'a, C, A>

Maximum number of results to return. Max allowed value is 100.

Sets the max results query property to the given value.

pub fn delegate( self, new_value: &'a mut dyn Delegate, ) -> MobiledeviceListCall<'a, C, A>

The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.

It should be used to handle progress information, and to implement a certain level of resilience.

Sets the delegate property to the given value.

pub fn param<T>(self, name: T, value: T) -> MobiledeviceListCall<'a, C, A>
where T: AsRef<str>,

Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.

Please note that this method must not be used to set any of the known parameters which have their own setter method. If done anyway, the request will fail.

Additional Parameters
  • quotaUser (query-string) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters.
  • oauth_token (query-string) - OAuth 2.0 token for the current user.
  • key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
  • prettyPrint (query-boolean) - Returns response with indentations and line breaks.
  • userIp (query-string) - Deprecated. Please use quotaUser instead.
  • fields (query-string) - Selector specifying which fields to include in a partial response.
  • alt (query-string) - Data format for the response.
pub fn add_scope<T, S>(self, scope: T) -> MobiledeviceListCall<'a, C, A>
where T: Into<Option<S>>, S: AsRef<str>,

Identifies the authorization scope for the method you are building.

Use this method to actively specify which scope should be used, instead the default Scope variant Scope::DirectoryDeviceMobileReadonly.

The scope will be added to a set of scopes. This is important as one can maintain access tokens for more than one scope. If None is specified, then all scopes will be removed and no default scope will be used either. In that case, you have to specify your API-key using the key parameter (see the param() function for details).

Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.