pub struct Privileges {
pub items: Option<Vec<Privilege>>,
pub kind: Option<String>,
pub etag: Option<String>,
}Expand description
JSON response template for List privileges operation in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list privileges (response)
Fields
items: Option<Vec<Privilege>>A list of Privilege resources.
kind: Option<String>The type of the API resource. This is always admin#directory#privileges.
etag: Option<String>ETag of the resource.