pub struct RoleAssignments {
pub next_page_token: Option<String>,
pub items: Option<Vec<RoleAssignment>>,
pub kind: Option<String>,
pub etag: Option<String>,
}Expand description
JSON response template for List roleAssignments operation in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list role assignments (response)
Fields
next_page_token: Option<String>no description provided
items: Option<Vec<RoleAssignment>>A list of RoleAssignment resources.
kind: Option<String>The type of the API resource. This is always admin#directory#roleAssignments.
etag: Option<String>ETag of the resource.