pub struct RoleRolePrivileges {
pub service_id: Option<String>,
pub privilege_name: Option<String>,
}Expand description
The set of privileges that are granted to this role.
This type is not used in any activity, and only used as part of another schema.
Fields
service_id: Option<String>The obfuscated ID of the service this privilege is for. This value is returned with Privileges.list().
privilege_name: Option<String>The name of the privilege.