pub struct SchemaFieldSpec {
pub kind: Option<String>,
pub display_name: Option<String>,
pub etag: Option<String>,
pub field_name: Option<String>,
pub field_type: Option<String>,
pub indexed: Option<bool>,
pub read_access_type: Option<String>,
pub numeric_indexing_spec: Option<SchemaFieldSpecNumericIndexingSpec>,
pub field_id: Option<String>,
pub multi_valued: Option<bool>,
}Expand description
JSON template for FieldSpec resource for Schemas in Directory API.
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>Kind of resource this is.
display_name: Option<String>Display Name of the field.
etag: Option<String>ETag of the resource.
field_name: Option<String>Name of the field.
field_type: Option<String>Type of the field.
indexed: Option<bool>Boolean specifying whether the field is indexed or not.
read_access_type: Option<String>Read ACLs on the field specifying who can view values of this field. Valid values are “ALL_DOMAIN_USERS” and “ADMINS_AND_SELF”.
numeric_indexing_spec: Option<SchemaFieldSpecNumericIndexingSpec>Indexing spec for a numeric field. By default, only exact match queries will be supported for numeric fields. Setting the numericIndexingSpec allows range queries to be supported.
field_id: Option<String>Unique identifier of Field (Read-only)
multi_valued: Option<bool>Boolean specifying whether this is a multi-valued field or not.