pub struct SchemaFieldSpecNumericIndexingSpec {
pub max_value: Option<f64>,
pub min_value: Option<f64>,
}Expand description
Indexing spec for a numeric field. By default, only exact match queries will be supported for numeric fields. Setting the numericIndexingSpec allows range queries to be supported.
This type is not used in any activity, and only used as part of another schema.
Fields
max_value: Option<f64>Maximum value of this field. This is meant to be indicative rather than enforced. Values outside this range will still be indexed, but search may not be as performant.
min_value: Option<f64>Minimum value of this field. This is meant to be indicative rather than enforced. Values outside this range will still be indexed, but search may not be as performant.