pub struct Tokens {
pub items: Option<Vec<Token>>,
pub kind: Option<String>,
pub etag: Option<String>,
}Expand description
JSON response template for List tokens operation in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list tokens (response)
Fields
items: Option<Vec<Token>>A list of Token resources.
kind: Option<String>The type of the API resource. This is always admin#directory#tokenList.
etag: Option<String>ETag of the resource.