Struct google_admin1_directory::VerificationCode [−][src]
pub struct VerificationCode {
pub kind: Option<String>,
pub etag: Option<String>,
pub user_id: Option<String>,
pub verification_code: Option<String>,
}JSON template for verification codes in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- invalidate verification codes (none)
- list verification codes (none)
- generate verification codes (none)
Fields
kind: Option<String>
The type of the resource. This is always admin#directory#verificationCode.
etag: Option<String>
ETag of the resource.
user_id: Option<String>
The obfuscated unique ID of the user.
verification_code: Option<String>
A current verification code for the user. Invalidated or used verification codes are not returned as part of the result.