Struct google_admin1_directory::Building [−][src]
pub struct Building {
pub kind: Option<String>,
pub etags: Option<String>,
pub description: Option<String>,
pub floor_names: Option<Vec<String>>,
pub building_id: Option<String>,
pub coordinates: Option<BuildingCoordinates>,
pub building_name: Option<String>,
}JSON template for Building object in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- buildings patch resources (request|response)
- buildings insert resources (request|response)
- buildings update resources (request|response)
- buildings get resources (response)
Fields
kind: Option<String>
Kind of resource this is.
ETag of the resource.
description: Option<String>
A brief description of the building. For example, "Chelsea Market".
floor_names: Option<Vec<String>>
The display names for all floors in this building. The floors are expected to be sorted in ascending order, from lowest floor to highest floor. For example, ["B2", "B1", "L", "1", "2", "2M", "3", "PH"] Must contain at least one entry.
building_id: Option<String>
Unique identifier for the building. The maximum length is 100 characters.
coordinates: Option<BuildingCoordinates>
The geographic coordinates of the center of the building, expressed as latitude and longitude in decimal degrees.
building_name: Option<String>
The building name as seen by users in Calendar. Must be unique for the customer. For example, "NYC-CHEL". The maximum length is 100 characters.