pub struct Member {
pub status: Option<String>,
pub kind: Option<String>,
pub delivery_settings: Option<String>,
pub email: Option<String>,
pub etag: Option<String>,
pub role: Option<String>,
pub type_: Option<String>,
pub id: Option<String>,
}Expand description
JSON template for Member resource in Directory API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- patch members (request|response)
- list members (none)
- insert members (request|response)
- get members (response)
- has member members (none)
- delete members (none)
- update members (request|response)
Fields
status: Option<String>Status of member (Immutable)
kind: Option<String>Kind of resource this is.
delivery_settings: Option<String>Delivery settings of member
email: Option<String>Email of member (Read-only)
etag: Option<String>ETag of the resource.
role: Option<String>Role of member
type_: Option<String>Type of member (Immutable)
id: Option<String>The unique ID of the group member. A member id can be used as a member request URI’s memberKey. Unique identifier of group (Read-only) Unique identifier of member (Read-only)